# Session YYYY-MM-DD

<!-- WRITE MODE: Append-only. Do not edit this file after the session ends.
     Create a new file for each calendar day: sessions/YYYY-MM-DD.md
     If multiple sessions occur in one day: sessions/YYYY-MM-DD-2.md -->

## Context

<!-- What task or query brought the agent to this room during this session. -->

<What was being worked on when this room was accessed.>

## Findings

<!-- What was learned, confirmed, or discovered. Include specifics — vague entries
     have no consolidation value. Prefer "K3s API server runs on 10.0.0.5:6443"
     over "checked cluster networking". -->

<What was learned or confirmed during this session.>

## Actions Taken

<!-- What was written, changed, or decided. Reference specific files if edited. -->

<What was written, changed, or decided.>

## Consolidation Notes

<!-- Flag anything that should be promoted to a canonical file on next consolidation.
     Be explicit: "promote X to Overview section of room-name.md" is more useful
     than "update the room". Leave blank if nothing warrants promotion. -->

<Anything to promote to a canonical file, or leave blank.>
